@@ -27,6 +27,13 @@ else
 	export CC="gcc-4.8"
 	export CXX="g++-4.8"
 fi
+
+# this is a workaround to fix the build on ppc64le due to the change in the host kernel on the ppc64le travis backend.
+if [[ "$arch" == "ppc64le" ]]; then
+	sudo apt-get install linux-headers-generic libelf-dev rpm
+	export KERNELDIR=/lib/modules/$(ls /lib/modules/|sort|head -1)/build
+fi
+
 wget https://github.com/Kitware/CMake/releases/download/v3.16.4/cmake-3.16.4.tar.gz
 tar -xzf cmake-3.16.4.tar.gz
 cd cmake-3.16.4
