@@ -10,11 +10,14 @@ or GPL2.txt for full copies of the license.
 #ifndef PPM_H_
 #define PPM_H_
 
+#ifndef UDIG
 #include <linux/version.h>
+#endif
 
 /*
  * Our Own ASSERT implementation, so we can easily switch among BUG_ON, WARN_ON and nothing
  */
+#ifndef UDIG
 #ifdef _DEBUG
 #define ASSERT(expr) WARN_ON(!(expr))
 #else
@@ -22,7 +25,6 @@ or GPL2.txt for full copies of the license.
 #endif
 
 #include <linux/time.h>
-typedef u64 nanoseconds;
 
 /*
  * Global defines
@@ -34,6 +36,7 @@ typedef u64 nanoseconds;
 #if (LINUX_VERSION_CODE > KERNEL_VERSION(3, 12, 0)) && defined(CONFIG_X86)
 #define CAPTURE_PAGE_FAULTS
 #endif
+#endif // UDIG
 #define RW_SNAPLEN_EVENT 4096
 #define DPI_LOOKAHEAD_SIZE 16
 #define PPM_NULL_RDEV MKDEV(1, 3)
@@ -42,6 +45,8 @@ typedef u64 nanoseconds;
 #define PPM_PORT_STATSD 8125
 #define PPM_PORT_MONGODB 27017
 
+typedef u64 nanoseconds;
+
 /*
  * The ring descriptor.
  * We have one of these for each CPU.
@@ -54,10 +59,13 @@ struct ppm_ring_buffer_context {
 	char *buffer;
 	nanoseconds last_print_time;
 	u32 nevents;
+#ifndef UDIG
 	atomic_t preempt_count;
+#endif	
 	char *str_storage;	/* String storage. Size is one page. */
 };
 
+#ifndef UDIG
 struct ppm_consumer_t {
 	struct task_struct *consumer_id;
 #ifdef __percpu
@@ -78,6 +86,7 @@ struct ppm_consumer_t {
 	uint16_t fullcapture_port_range_end;
 	uint16_t statsd_port;
 };
+#endif // UDIG
 
 #define STR_STORAGE_SIZE PAGE_SIZE
 
@@ -88,8 +97,10 @@ struct ppm_consumer_t {
  * but they can't sleep, barf on page fault or be preempted
  */
 #define ppm_get_user(x, ptr) ({ ppm_copy_from_user(&x, ptr, sizeof(x)) ? -EFAULT : 0; })
+#ifndef UDIG
 unsigned long ppm_copy_from_user(void *to, const void __user *from, unsigned long n);
 long ppm_strncpy_from_user(char *to, const char __user *from, unsigned long n);
+#endif // UDIG
 
 /*
  * Global tables
@@ -116,7 +127,9 @@ extern const struct syscall_evt_pair g_syscall_ia32_table[];
 extern const enum ppm_syscall_code g_syscall_ia32_code_routing_table[];
 #endif
 
+#ifndef UDIG
 extern void ppm_syscall_get_arguments(struct task_struct *task, struct pt_regs *regs, unsigned long *args);
+#endif
 
 #define NS_TO_SEC(_ns) ((_ns) / 1000000000)
 #define MORE_THAN_ONE_SECOND_AHEAD(_ns1, _ns2) ((_ns1) - (_ns2) > 1000000000)
