@@ -9,12 +9,12 @@ or GPL2.txt for full copies of the license.
 
 #ifndef PPM_FLAG_HELPERS_H_
 #define PPM_FLAG_HELPERS_H_
-
-#include <asm/mman.h>
+#ifndef UDIG
+#include <linux/mman.h>
 #include <linux/futex.h>
 #include <linux/ptrace.h>
-
 #include "ppm.h"
+#endif
 
 #define PPM_MS_MGC_MSK 0xffff0000
 #define PPM_MS_MGC_VAL 0xC0ED0000
@@ -37,6 +37,10 @@ static __always_inline uint32_t open_flags_to_scap(unsigned long flags)
 
 	if (flags & O_CREAT)
 		res |= PPM_O_CREAT;
+#ifdef O_TMPFILE
+	if (flags & O_TMPFILE)
+		res |= PPM_O_TMPFILE;
+#endif
 
 	if (flags & O_APPEND)
 		res |= PPM_O_APPEND;
@@ -84,11 +88,15 @@ static __always_inline uint32_t open_flags_to_scap(unsigned long flags)
 static __always_inline u32 open_modes_to_scap(unsigned long flags,
 					      unsigned long modes)
 {
+#ifdef UDIG
+	unsigned long flags_mask = O_CREAT | O_TMPFILE;
+#else
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 11, 0)
 	unsigned long flags_mask = O_CREAT | O_TMPFILE;
 #else
 	unsigned long flags_mask = O_CREAT;
 #endif
+#endif /* UDIG */
 	u32 res = 0;
 
 	if ((flags & flags_mask) == 0)
@@ -356,8 +364,10 @@ static __always_inline u32 prot_flags_to_scap(int prot)
 	if (prot & PROT_EXEC)
 		res |= PPM_PROT_EXEC;
 
+#ifdef PROT_SEM
 	if (prot & PROT_SEM)
 		res |= PPM_PROT_SEM;
+#endif
 
 	if (prot & PROT_GROWSDOWN)
 		res |= PPM_PROT_GROWSDOWN;
@@ -458,6 +468,7 @@ static __always_inline u8 fcntl_cmd_to_scap(unsigned long cmd)
 		return PPM_FCNTL_F_SETSIG;
 	case F_GETSIG:
 		return PPM_FCNTL_F_GETSIG;
+#ifndef UDIG
 #ifndef CONFIG_64BIT
 	case F_GETLK64:
 		return PPM_FCNTL_F_GETLK64;
@@ -466,6 +477,7 @@ static __always_inline u8 fcntl_cmd_to_scap(unsigned long cmd)
 	case F_SETLKW64:
 		return PPM_FCNTL_F_SETLKW64;
 #endif
+#endif /* UDIG */
 #ifdef F_SETOWN_EX
 	case F_SETOWN_EX:
 		return PPM_FCNTL_F_SETOWN_EX;
@@ -512,6 +524,245 @@ static __always_inline u8 fcntl_cmd_to_scap(unsigned long cmd)
 	}
 }
 
+static __always_inline u8 sockopt_level_to_scap(int level)
+{
+	switch (level) {
+		case SOL_SOCKET:
+			return PPM_SOCKOPT_LEVEL_SOL_SOCKET;
+		case SOL_TCP:
+			return PPM_SOCKOPT_LEVEL_SOL_TCP;
+		default:
+			/* no ASSERT as there are legitimate other levels we don't just support yet */
+			return PPM_SOCKOPT_LEVEL_UNKNOWN;
+	}
+}
+
+static __always_inline u8 sockopt_optname_to_scap(int level, int optname)
+{
+	if (level != SOL_SOCKET)
+	{
+		/* no ASSERT as there are legitimate other levels we don't just support yet */
+		return PPM_SOCKOPT_LEVEL_UNKNOWN;
+	}
+	switch (optname) {
+#ifdef SO_DEBUG
+		case SO_DEBUG:
+			return PPM_SOCKOPT_SO_DEBUG;
+#endif
+#ifdef SO_REUSEADDR
+		case SO_REUSEADDR:
+			return PPM_SOCKOPT_SO_REUSEADDR;
+#endif
+#ifdef SO_TYPE
+		case SO_TYPE:
+			return PPM_SOCKOPT_SO_TYPE;
+#endif
+#ifdef SO_ERROR
+		case SO_ERROR:
+			return PPM_SOCKOPT_SO_ERROR;
+#endif
+#ifdef SO_DONTROUTE
+		case SO_DONTROUTE:
+			return PPM_SOCKOPT_SO_DONTROUTE;
+#endif
+#ifdef SO_BROADCAST
+		case SO_BROADCAST:
+			return PPM_SOCKOPT_SO_BROADCAST;
+#endif
+#ifdef SO_SNDBUF
+		case SO_SNDBUF:
+			return PPM_SOCKOPT_SO_SNDBUF;
+#endif
+#ifdef SO_RCVBUF
+		case SO_RCVBUF:
+			return PPM_SOCKOPT_SO_RCVBUF;
+#endif
+#ifdef SO_SNDBUFFORCE
+		case SO_SNDBUFFORCE:
+			return PPM_SOCKOPT_SO_SNDBUFFORCE;
+#endif
+#ifdef SO_RCVBUFFORCE
+		case SO_RCVBUFFORCE:
+			return PPM_SOCKOPT_SO_RCVBUFFORCE;
+#endif
+#ifdef SO_KEEPALIVE
+		case SO_KEEPALIVE:
+			return PPM_SOCKOPT_SO_KEEPALIVE;
+#endif
+#ifdef SO_OOBINLINE
+		case SO_OOBINLINE:
+			return PPM_SOCKOPT_SO_OOBINLINE;
+#endif
+#ifdef SO_NO_CHECK
+		case SO_NO_CHECK:
+			return PPM_SOCKOPT_SO_NO_CHECK;
+#endif
+#ifdef SO_PRIORITY
+		case SO_PRIORITY:
+			return PPM_SOCKOPT_SO_PRIORITY;
+#endif
+#ifdef SO_LINGER
+		case SO_LINGER:
+			return PPM_SOCKOPT_SO_LINGER;
+#endif
+#ifdef SO_BSDCOMPAT
+		case SO_BSDCOMPAT:
+			return PPM_SOCKOPT_SO_BSDCOMPAT;
+#endif
+#ifdef SO_REUSEPORT
+		case SO_REUSEPORT:
+			return PPM_SOCKOPT_SO_REUSEPORT;
+#endif
+#ifdef SO_PASSCRED
+		case SO_PASSCRED:
+			return PPM_SOCKOPT_SO_PASSCRED;
+#endif
+#ifdef SO_PEERCRED
+		case SO_PEERCRED:
+			return PPM_SOCKOPT_SO_PEERCRED;
+#endif
+#ifdef SO_RCVLOWAT
+		case SO_RCVLOWAT:
+			return PPM_SOCKOPT_SO_RCVLOWAT;
+#endif
+#ifdef SO_SNDLOWAT
+		case SO_SNDLOWAT:
+			return PPM_SOCKOPT_SO_SNDLOWAT;
+#endif
+#ifdef SO_RCVTIMEO
+		case SO_RCVTIMEO:
+			return PPM_SOCKOPT_SO_RCVTIMEO;
+#endif
+#ifdef SO_SNDTIMEO
+		case SO_SNDTIMEO:
+			return PPM_SOCKOPT_SO_SNDTIMEO;
+#endif
+#ifdef SO_SECURITY_AUTHENTICATION
+		case SO_SECURITY_AUTHENTICATION:
+			return PPM_SOCKOPT_SO_SECURITY_AUTHENTICATION;
+#endif
+#ifdef SO_SECURITY_ENCRYPTION_TRANSPORT
+		case SO_SECURITY_ENCRYPTION_TRANSPORT:
+			return PPM_SOCKOPT_SO_SECURITY_ENCRYPTION_TRANSPORT;
+#endif
+#ifdef SO_SECURITY_ENCRYPTION_NETWORK
+		case SO_SECURITY_ENCRYPTION_NETWORK:
+			return PPM_SOCKOPT_SO_SECURITY_ENCRYPTION_NETWORK;
+#endif
+#ifdef SO_BINDTODEVICE
+		case SO_BINDTODEVICE:
+			return PPM_SOCKOPT_SO_BINDTODEVICE;
+#endif
+#ifdef SO_ATTACH_FILTER
+		case SO_ATTACH_FILTER:
+			return PPM_SOCKOPT_SO_ATTACH_FILTER;
+#endif
+#ifdef SO_DETACH_FILTER
+		case SO_DETACH_FILTER:
+			return PPM_SOCKOPT_SO_DETACH_FILTER;
+#endif
+#ifdef SO_PEERNAME
+		case SO_PEERNAME:
+			return PPM_SOCKOPT_SO_PEERNAME;
+#endif
+#ifdef SO_TIMESTAMP
+		case SO_TIMESTAMP:
+			return PPM_SOCKOPT_SO_TIMESTAMP;
+#endif
+#ifdef SO_ACCEPTCONN
+		case SO_ACCEPTCONN:
+			return PPM_SOCKOPT_SO_ACCEPTCONN;
+#endif
+#ifdef SO_PEERSEC
+		case SO_PEERSEC:
+			return PPM_SOCKOPT_SO_PEERSEC;
+#endif
+#ifdef SO_PASSSEC
+		case SO_PASSSEC:
+			return PPM_SOCKOPT_SO_PASSSEC;
+#endif
+#ifdef SO_TIMESTAMPNS
+		case SO_TIMESTAMPNS:
+			return PPM_SOCKOPT_SO_TIMESTAMPNS;
+#endif
+#ifdef SO_MARK
+		case SO_MARK:
+			return PPM_SOCKOPT_SO_MARK;
+#endif
+#ifdef SO_TIMESTAMPING
+		case SO_TIMESTAMPING:
+			return PPM_SOCKOPT_SO_TIMESTAMPING;
+#endif
+#ifdef SO_PROTOCOL
+		case SO_PROTOCOL:
+			return PPM_SOCKOPT_SO_PROTOCOL;
+#endif
+#ifdef SO_DOMAIN
+		case SO_DOMAIN:
+			return PPM_SOCKOPT_SO_DOMAIN;
+#endif
+#ifdef SO_RXQ_OVFL
+		case SO_RXQ_OVFL:
+			return PPM_SOCKOPT_SO_RXQ_OVFL;
+#endif
+#ifdef SO_WIFI_STATUS
+		case SO_WIFI_STATUS:
+			return PPM_SOCKOPT_SO_WIFI_STATUS;
+#endif
+#ifdef SO_PEEK_OFF
+		case SO_PEEK_OFF:
+			return PPM_SOCKOPT_SO_PEEK_OFF;
+#endif
+#ifdef SO_NOFCS
+		case SO_NOFCS:
+			return PPM_SOCKOPT_SO_NOFCS;
+#endif
+#ifdef SO_LOCK_FILTER
+		case SO_LOCK_FILTER:
+			return PPM_SOCKOPT_SO_LOCK_FILTER;
+#endif
+#ifdef SO_SELECT_ERR_QUEUE
+		case SO_SELECT_ERR_QUEUE:
+			return PPM_SOCKOPT_SO_SELECT_ERR_QUEUE;
+#endif
+#ifdef SO_BUSY_POLL
+		case SO_BUSY_POLL:
+			return PPM_SOCKOPT_SO_BUSY_POLL;
+#endif
+#ifdef SO_MAX_PACING_RATE
+		case SO_MAX_PACING_RATE:
+			return PPM_SOCKOPT_SO_MAX_PACING_RATE;
+#endif
+#ifdef SO_BPF_EXTENSIONS
+		case SO_BPF_EXTENSIONS:
+			return PPM_SOCKOPT_SO_BPF_EXTENSIONS;
+#endif
+#ifdef SO_INCOMING_CPU
+		case SO_INCOMING_CPU:
+			return PPM_SOCKOPT_SO_INCOMING_CPU;
+#endif
+#ifdef SO_ATTACH_BPF
+		case SO_ATTACH_BPF:
+			return PPM_SOCKOPT_SO_ATTACH_BPF;
+#endif
+#ifdef SO_PEERGROUPS
+		case SO_PEERGROUPS:
+			return PPM_SOCKOPT_SO_PEERGROUPS;
+#endif
+#ifdef SO_MEMINFO
+		case SO_MEMINFO:
+			return PPM_SOCKOPT_SO_MEMINFO;
+#endif
+#ifdef SO_COOKIE
+		case SO_COOKIE:
+			return PPM_SOCKOPT_SO_COOKIE;
+#endif
+		default:
+			ASSERT(false);
+			return PPM_SOCKOPT_UNKNOWN;
+	}
+}
+
 /* XXX this is very basic for the moment, we'll need to improve it */
 static __always_inline u16 poll_events_to_scap(short revents)
 {
@@ -556,6 +807,7 @@ static __always_inline u16 poll_events_to_scap(short revents)
 static __always_inline u16 futex_op_to_scap(unsigned long op)
 {
 	u16 res = 0;
+#ifndef UDIG
 	unsigned long flt_op = op & 127;
 
 	if (flt_op == FUTEX_WAIT)
@@ -600,7 +852,7 @@ static __always_inline u16 futex_op_to_scap(unsigned long op)
 	if (op & FUTEX_CLOCK_REALTIME)
 		res |= PPM_FU_FUTEX_CLOCK_REALTIME;
 #endif
-
+#endif /* UDIG */
 	return res;
 }
 
@@ -611,12 +863,21 @@ static __always_inline u32 access_flags_to_scap(unsigned flags)
 	if (flags == 0/*F_OK*/) {
 		res = PPM_F_OK;
 	} else {
+#ifdef UDIG
+		if (flags & X_OK)
+			res |= PPM_X_OK;
+		if (flags & R_OK)
+			res |= PPM_R_OK;
+		if (flags & W_OK)
+			res |= PPM_W_OK;
+#else
 		if (flags & MAY_EXEC)
 			res |= PPM_X_OK;
 		if (flags & MAY_READ)
 			res |= PPM_R_OK;
 		if (flags & MAY_WRITE)
 			res |= PPM_W_OK;
+#endif
 	}
 
 	return res;
@@ -711,7 +972,7 @@ static __always_inline u32 pf_flags_to_scap(unsigned long flags)
 	u32 res = 0;
 
 	/* Page fault error codes don't seem to be clearly defined in header
-	 * files througout the kernel except in some emulation modes (e.g. kvm)
+	 * files throughout the kernel except in some emulation modes (e.g. kvm)
 	 * which we can't assume to exist, so I just took the definitions from
 	 * the x86 manual. If we end up supporting another arch for page faults,
 	 * refactor this.
@@ -802,6 +1063,7 @@ static __always_inline uint16_t quotactl_cmd_to_scap(unsigned long cmd)
 	/*
 	 *  XFS specific
 	 */
+#ifndef UDIG
 	case Q_XQUOTAON:
 		res = PPM_Q_XQUOTAON;
 		break;
@@ -823,6 +1085,7 @@ static __always_inline uint16_t quotactl_cmd_to_scap(unsigned long cmd)
 	case Q_XQUOTASYNC:
 		res = PPM_Q_XQUOTASYNC;
 		break;
+#endif		
 	default:
 		res = 0;
 	}
@@ -986,14 +1249,18 @@ static __always_inline u16 ptrace_requests_to_scap(unsigned long req)
 		return PPM_PTRACE_KILL;
 	case PTRACE_CONT:
 		return PPM_PTRACE_CONT;
+#ifdef PTRACE_POKEUSR
 	case PTRACE_POKEUSR:
 		return PPM_PTRACE_POKEUSR;
+#endif		
 	case PTRACE_POKEDATA:
 		return PPM_PTRACE_POKEDATA;
 	case PTRACE_POKETEXT:
 		return PPM_PTRACE_POKETEXT;
+#ifdef PTRACE_PEEKUSR
 	case PTRACE_PEEKUSR:
 		return PPM_PTRACE_PEEKUSR;
+#endif
 	case PTRACE_PEEKDATA:
 		return PPM_PTRACE_PEEKDATA;
 	case PTRACE_PEEKTEXT:
@@ -1030,4 +1297,58 @@ static __always_inline u32 linkat_flags_to_scap(unsigned long flags)
 	return res;
 }
 
+static __always_inline u32 chmod_mode_to_scap(unsigned long modes)
+{
+	u32 res = 0;
+	if (modes & S_IRUSR)
+		res |= PPM_S_IRUSR;
+
+	if (modes & S_IWUSR)
+		res |= PPM_S_IWUSR;
+
+	if (modes & S_IXUSR)
+		res |= PPM_S_IXUSR;
+
+	/*
+	 * PPM_S_IRWXU == S_IRUSR | S_IWUSR | S_IXUSR
+	 */
+
+	if (modes & S_IRGRP)
+		res |= PPM_S_IRGRP;
+
+	if (modes & S_IWGRP)
+		res |= PPM_S_IWGRP;
+
+	if (modes & S_IXGRP)
+		res |= PPM_S_IXGRP;
+
+	/*
+	 * PPM_S_IRWXG == S_IRGRP | S_IWGRP | S_IXGRP
+	 */
+
+	if (modes & S_IROTH)
+		res |= PPM_S_IROTH;
+
+	if (modes & S_IWOTH)
+		res |= PPM_S_IWOTH;
+
+	if (modes & S_IXOTH)
+		res |= PPM_S_IXOTH;
+
+	/*
+	 * PPM_S_IRWXO == S_IROTH | S_IWOTH | S_IXOTH
+	 */
+
+	if (modes & S_ISUID)
+		res |= PPM_S_ISUID;
+
+	if (modes & S_ISGID)
+		res |= PPM_S_ISGID;
+
+	if (modes & S_ISVTX)
+		res |= PPM_S_ISVTX;
+
+	return res;
+}
+
 #endif /* PPM_FLAG_HELPERS_H_ */
