@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2013-2018 Draios Inc. dba Sysdig.
+Copyright (c) 2020 Sysdig Inc
 
 This file is dual licensed under either the MIT or GPL 2. See MIT.txt
 or GPL2.txt for full copies of the license.
@@ -26,10 +26,19 @@ or GPL2.txt for full copies of the license.
 #include <asm/syscall.h>
 #endif
 #else /* __KERNEL__ */
+#ifdef UDIG
+#include <sys/syscall.h>
+#else  /* UDIG */
 #include <linux/unistd.h>
+#endif /* UDIG */
+#ifdef __mips__
+#define SYSCALL_TABLE_ID0 __NR_Linux
+#else /* __mips__ */
 #define SYSCALL_TABLE_ID0 0
+#endif /* __mips__ */
 #endif /* __KERNEL__ */
 
+
 #include "ppm_events_public.h"
 #ifdef __KERNEL__
 #include "ppm.h"
@@ -288,6 +297,9 @@ const struct syscall_evt_pair g_syscall_table[SYSCALL_TABLE_SIZE] = {
 #ifdef __NR_seccomp
 	[__NR_seccomp - SYSCALL_TABLE_ID0] =                    {UF_USED, PPME_SYSCALL_SECCOMP_E, PPME_SYSCALL_SECCOMP_X},
 #endif
+#ifdef __NR_renameat2
+	[__NR_renameat2 - SYSCALL_TABLE_ID0] =                   {UF_USED, PPME_SYSCALL_RENAMEAT2_E, PPME_SYSCALL_RENAMEAT2_X},
+#endif
 };
 
 /*
@@ -839,6 +851,9 @@ const enum ppm_syscall_code g_syscall_code_routing_table[SYSCALL_TABLE_SIZE] = {
 #ifdef __NR_fadvise64
 	[__NR_fadvise64 - SYSCALL_TABLE_ID0] = PPM_SC_FADVISE64,
 #endif
+#ifdef __NR_renameat2
+	[__NR_renameat2 - SYSCALL_TABLE_ID0] = PPM_SC_RENAMEAT2,
+#endif
 };
 
 #ifdef CONFIG_IA32_EMULATION
@@ -1072,6 +1087,9 @@ const struct syscall_evt_pair g_syscall_ia32_table[SYSCALL_TABLE_SIZE] = {
 #ifdef __NR_ia32_seccomp
 	[__NR_ia32_seccomp - SYSCALL_TABLE_ID0] =                    {UF_USED, PPME_SYSCALL_SECCOMP_E, PPME_SYSCALL_SECCOMP_X},
 #endif
+#ifdef __NR_ia32_renameat2
+	[__NR_ia32_renameat2 - SYSCALL_TABLE_ID0] =                  {UF_USED, PPME_SYSCALL_RENAMEAT2_E, PPME_SYSCALL_RENAMEAT2_X},
+#endif
 };
 
 /*
@@ -1625,6 +1643,9 @@ const enum ppm_syscall_code g_syscall_ia32_code_routing_table[SYSCALL_TABLE_SIZE
 #ifdef __NR_ia32_fadvise64
 	[__NR_ia32_fadvise64 - SYSCALL_TABLE_ID0] = PPM_SC_FADVISE64,
 #endif
+#ifdef __NR_ia32_renameat2
+	[__NR_ia32_renameat2 - SYSCALL_TABLE_ID0] = PPM_SC_RENAMEAT2,
+#endif
 };
 
 #endif /* CONFIG_IA32_EMULATION */
