@@ -19,8 +19,6 @@ limitations under the License.
 #ifndef __COMPAT_MISC_H
 #define __COMPAT_MISC_H
 
-#include "bpf.h"
-
 #ifndef __NR_bpf
 #ifdef __x86_64__
 #define __NR_bpf 321
@@ -33,16 +31,12 @@ limitations under the License.
 #define CLOCK_BOOTTIME 7
 #endif
 
-static int sys_bpf(enum bpf_cmd cmd, union bpf_attr *attr, unsigned int size)
-{
-	return syscall(__NR_bpf, cmd, attr, size);
-}
-
-static int sys_perf_event_open(struct perf_event_attr *attr,
-			       pid_t pid, int cpu, int group_fd,
-			       unsigned long flags)
-{
-	return syscall(__NR_perf_event_open, attr, pid, cpu, group_fd, flags);
-}
+/*
+	O_TMPFILE was introduced in Linux >= 3.11 and defined as (__O_TMPFILE | O_DIRECTORY).
+	To maintain compatiblity with different build environments, the below is added.   
+*/
+#ifndef O_TMPFILE
+#define O_TMPFILE 020200000
+#endif
 
 #endif
