@@ -1,19 +1,20 @@
 /*
-Copyright (C) 2013-2014 Draios inc.
+Copyright (C) 2013-2018 Draios Inc dba Sysdig.
 
 This file is part of sysdig.
 
-sysdig is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License version 2 as
-published by the Free Software Foundation.
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
 
-sysdig is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+    http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
 
-You should have received a copy of the GNU General Public License
-along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <stdio.h>
@@ -34,7 +35,7 @@ size_t g_get_event_size(enum ppm_event_type event_type, uint16_t* lens)
 	int32_t res = 0;
 
 	for(j = 0; j < g_event_info[event_type].nparams; j++)
-	{	
+	{
 		res += lens[j];
 	}
 
@@ -101,7 +102,7 @@ int32_t g_check_integrity(uint32_t* cur_event, char* copy_buffer, int buf_len, O
 #ifdef PPM_ENABLE_SENTINEL
 		sentinel_begin = ((struct ppm_evt_hdr*)(copy_buffer + offset))->sentinel_begin;
 		sentinel_end = *(uint32_t*)(copy_buffer + offset + event_size - sizeof(uint32_t));
-		
+
 		if(sentinel_begin != sentinel_end)
 		{
 			fprintf(stderr, "Error: sentinel begin %d, sentinel end %d, evt_type %u, evt_size %zu, cnt %u, offset %x, remaining %u\n",
@@ -197,7 +198,7 @@ int main()
 		{
 			uint32_t nevents;
 
-			ret = scap_readbuf(h, j, false, &buf, &buflen);
+			ret = scap_readbuf(h, j, &buf, &buflen);
 
 			if(ret != SCAP_SUCCESS)
 			{
@@ -253,7 +254,7 @@ int main()
 			{
 				fprintf(stderr, "%s\n", scap_getlasterr(h));
 				scap_close(h);
-				return -1;				
+				return -1;
 			}
 
 			printf("bps:%" PRIu64 " totbytes:%" PRIu64 " - evts/s:%" PRIu64 " totevs:%" PRIu64 " drops:%" PRIu64 "\n",
