@@ -18,4 +18,4 @@ limitations under the License.
 */
 #pragma once
 
-int32_t scap_proc_scan_proc_dir_windows(scap_t* handle, struct scap_threadinfo** procinfo, char *error);
+int32_t scap_proc_scan_proc_dir_windows(scap_t* handle, char *error);
