@@ -21,23 +21,27 @@ limitations under the License.
 
 #include <string>
 
-class sinsp_container_manager;
 class sinsp_container_info;
 class sinsp_threadinfo;
 
-#include "container_engine/container_engine.h"
+#include "container_engine/container_engine_base.h"
+#include "sinsp_container_type.h"
 
 namespace libsinsp {
 namespace container_engine {
-class rkt : public resolver {
+class rkt : public container_engine_base
+{
 public:
-	bool resolve(sinsp_container_manager *manager, sinsp_threadinfo *tinfo, bool query_os_for_missing_info) override;
+	rkt(container_cache_interface& cache) : container_engine_base(cache)
+	{}
+
+	bool resolve(sinsp_threadinfo *tinfo, bool query_os_for_missing_info) override;
 
 protected:
-	bool match(sinsp_container_manager *manager, sinsp_threadinfo *tinfo, sinsp_container_info *container_info,
-		   std::string &rkt_podid, std::string &rkt_appname, bool query_os_for_missing_info);
+	bool match(container_cache_interface *cache, sinsp_threadinfo *tinfo, sinsp_container_info& container_info,
+		   std::string& rkt_podid, std::string& rkt_appname, bool query_os_for_missing_info);
 
-	bool parse_rkt(sinsp_container_info *container, const std::string &podid, const std::string &appname);
+	bool parse_rkt(sinsp_container_info& container, const std::string& podid, const std::string& appname);
 };
 }
 }
