@@ -21,7 +21,7 @@ limitations under the License.
 //
 // kubernetes REST API notification abstraction
 //
-
+#ifndef MINIMAL_BUILD
 #pragma once
 
 #include "k8s.h"
@@ -226,4 +226,6 @@ inline const std::string& k8s_dispatcher::next_msg()
 inline void k8s_dispatcher::remove()
 {
 	m_messages.pop_front();
-}
\ No newline at end of file
+}
+
+#endif // MINIMAL_BUILD
\ No newline at end of file
