@@ -21,6 +21,7 @@ limitations under the License.
 //
 // connects and gets the data from k8s_net REST API interface
 //
+#ifndef MINIMAL_BUILD
 #pragma once
 
 #include "k8s_component.h"
@@ -56,4 +57,5 @@ inline k8s_component::type k8s_event_data::component() const
 inline std::string k8s_event_data::data() const
 {
 	return m_data;
-}
\ No newline at end of file
+}
+#endif // MINIMAL_BUILD
\ No newline at end of file
