@@ -19,7 +19,7 @@ limitations under the License.
 //
 // k8s_namespace_handler.h
 //
-
+#ifndef MINIMAL_BUILD
 #pragma once
 
 #include "json/json.h"
@@ -52,3 +52,5 @@ private:
 
 	bool handle_component(const Json::Value& json, const msg_data* data = 0);
 };
+
+#endif // MINIMAL_BUILD
\ No newline at end of file
