@@ -19,7 +19,7 @@ limitations under the License.
 //
 // marathon_http.h
 //
-
+#ifndef MINIMAL_BUILD
 #pragma once
 
 #ifdef HAS_CAPTURE
@@ -47,3 +47,4 @@ private:
 };
 
 #endif // HAS_CAPTURE
+#endif // MINIMAL_BUILD
\ No newline at end of file
