@@ -20,11 +20,13 @@ limitations under the License.
 //
 // socket_handler.h
 //
-
+#ifndef MINIMAL_BUILD
 #pragma once
 
 #ifdef HAS_CAPTURE
 
+#include "ares.h"
+#include "addrinfo.h"
 #include "http_parser.h"
 #include "uri.h"
 #include "json/json.h"
@@ -57,23 +59,6 @@ limitations under the License.
 #define SOCK_NONBLOCK 0
 #endif
 
-struct gaicb_free
-{
-	void operator() (struct gaicb **reqs) const
-		{
-			if(reqs[0]->ar_result)
-			{
-				freeaddrinfo(reqs[0]->ar_result);
-			}
-			if(reqs[0]->ar_name)
-			{
-				free((void*)reqs[0]->ar_name);
-			}
-			free(reqs[0]);
-			free(reqs);
-		}
-};
-
 template <typename T>
 class socket_data_handler
 {
@@ -501,7 +486,7 @@ public:
 					ASSERT(!m_data_buf.size());
 					m_data_buf.clear();
 				}
-				// In HTTP 1.1 connnections with chunked transfer, this socket may never be closed by server,
+				// In HTTP 1.1 connections with chunked transfer, this socket may never be closed by server,
 				// (K8s API server is an example of such behavior), in which case the chunked data will just
 				// stop flowing. We can keep the good socket and resend the request instead of severing the
 				// connection. The m_wants_send flag has to be checked by the caller and request re-sent, otherwise
@@ -1323,100 +1308,60 @@ private:
 
 	bool try_resolve()
 	{
-		if(is_resolved())
+		if (is_resolved())
 		{
 			return true;
 		}
 		else
 		{
-			if(inet_aton(m_url.get_host().c_str(), &m_serv_addr.sin_addr)) // IP address provided
+			if (inet_aton(m_url.get_host().c_str(), &m_serv_addr.sin_addr)) // IP address provided
 			{
 				m_address = m_url.get_host();
 			}
 			else // name provided, resolve to IP address
 			{
 				m_serv_addr = {0};
-				int ret = 0;
-				if(!m_dns_reqs) // first call, call async resolver
+
+				if (!m_ares_cb_res.call) // first call, call async resolver
 				{
 					g_logger.log("Socket handler (" + m_id + ") resolving " + m_url.get_host(),
 								 sinsp_logger::SEV_TRACE);
-					m_dns_reqs = make_gaicb(m_url.get_host());
-					ret = getaddrinfo_a(GAI_NOWAIT, m_dns_reqs.get(), 1, NULL);
-					if(ret)
-					{
-						throw sinsp_exception("Socket handler (" + m_id + "): " + m_url.get_host() +
-									 " getaddrinfo_a() failed: " + gai_strerror(ret));
-					}
+
+					ares_init_options(&m_ares_channel, &m_ares_opts, 0);
+					ares_gethostbyname(m_ares_channel, m_url.get_host().c_str(), AF_INET, ares_cb, &m_ares_cb_res);
+					m_ares_cb_res.call = true;
+
 					return false;
 				}
-				else // rest of the calls, try to get resolver result
+				else if (!m_ares_cb_res.done)
 				{
-					g_logger.log("Socket handler (" + m_id + ") checking resolve for " + m_url.get_host(),
-								 sinsp_logger::SEV_TRACE);
-					ret = gai_error(m_dns_reqs[0]);
-					g_logger.log("Socket handler (" + m_id + ") gai_error=" + std::to_string(ret),
-								 sinsp_logger::SEV_TRACE);
-					if(!ret)
+					int nfds;
+					fd_set read_fds, write_fds;
+					nfds = ares_fds(m_ares_channel, &read_fds, &write_fds);
+					if (nfds == 0)
 					{
-						if(m_dns_reqs && m_dns_reqs[0] && m_dns_reqs[0]->ar_result)
-						{
-							for (struct addrinfo* ai = m_dns_reqs[0]->ar_result; ai; ai = ai->ai_next)
-							{
-								if(ai->ai_addrlen && ai->ai_addr && ai->ai_addr->sa_family == AF_INET)
-								{
-									struct sockaddr_in* saddr = (struct sockaddr_in*)ai->ai_addr;
-									if(saddr->sin_addr.s_addr)
-									{
-										m_serv_addr.sin_addr.s_addr = saddr->sin_addr.s_addr;
-										m_address = inet_ntoa(saddr->sin_addr);
-										g_logger.log("Socket handler (" + m_id + "): " + m_url.get_host() +
-													 " resolved to " + m_address, sinsp_logger::SEV_TRACE);
-										dns_cleanup();
-										break;
-									}
-								}
-							}
-							if(!m_serv_addr.sin_addr.s_addr)
-							{
-								g_logger.log("Socket handler (" + m_id + "): " + m_url.get_host() +
-											 " address not resolved yet.", sinsp_logger::SEV_TRACE);
-								return false;
-							}
-						}
-						else
-						{
-							throw sinsp_exception("Socket handler (" + m_id + "): " + m_url.get_host() +
-												  ", resolver request is NULL.");
-						}
-					}
-					else
-					{
-						switch(ret)
-						{
-							case EAI_AGAIN:
-							case EAI_INPROGRESS:
-								g_logger.log("Socket handler (" + m_id + ") [" + m_url.get_host() + "]: " +
-											 gai_strerror(ret), sinsp_logger::SEV_DEBUG);
-								break;
-							case EAI_SYSTEM:
-								g_logger.log("Socket handler (" + m_id + ") [" + m_url.get_host() + "]: " +
-											 ", resolver error: " + gai_strerror(ret) +
-											 ", system error: " + strerror(errno), sinsp_logger::SEV_ERROR);
-								break;
-							default:
-								g_logger.log("Socket handler (" + m_id + ") [" + m_url.get_host() + "]: " +
-											 ", resolver error: " + gai_strerror(ret),
-											 sinsp_logger::SEV_ERROR);
-						}
 						return false;
 					}
+					ares_process(m_ares_channel, &read_fds, &write_fds);
+					return false;
+				}
+				else // rest of the calls, check if address was resolved
+				{
+					if (m_ares_cb_res.address.empty())
+					{
+						g_logger.log("Socket handler (" + m_id + "): " + m_url.get_host() +
+										 " address not resolved yet.",
+									 sinsp_logger::SEV_TRACE);
+						return false;
+					}
+					m_address = m_ares_cb_res.address;
+					m_serv_addr.sin_addr = m_ares_cb_res.addr;
 				}
 			}
 		}
 		m_serv_addr.sin_family = AF_INET;
 		m_serv_addr.sin_port = htons(m_url.get_port());
-		m_sa = (sockaddr*)&m_serv_addr;
+		m_sa = (sockaddr *)&m_serv_addr;
 		m_sa_len = sizeof(struct sockaddr_in);
 		return true;
 	}
@@ -1487,68 +1432,6 @@ private:
 		m_connect_called = true;
 	}
 
-	bool dns_req_done(struct gaicb** dns_reqs) const
-	{
-		if(dns_reqs && dns_reqs[0])
-		{
-			int ret = gai_cancel(dns_reqs[0]);
-			int err = gai_error(dns_reqs[0]);
-			if(ret == EAI_ALLDONE || err == EAI_CANCELED)
-			{
-				return true;
-			}
-			else if(err == EAI_INPROGRESS || err == EAI_AGAIN)
-			{
-				std::string errstr = (err == EAI_INPROGRESS ) ?
-									"processing in progress" :
-									"resources temporarily unavailable";
-				g_logger.log("Socket handler (" + m_id + ") connection [" + m_url.to_string(false) + "], "
-							 " cancelling DNS request postponed (" + errstr + ")"
-							 "\n err: (" + std::to_string(err) + ") " + gai_strerror(err),
-							 sinsp_logger::SEV_DEBUG);
-				return false;
-			}
-			else
-			{
-				g_logger.log("Socket handler (" + m_id + ") connection [" + m_url.to_string(false) + "], "
-							 "error canceling DNS request"
-							 "\n ret: (" + std::to_string(ret) + ") " + gai_strerror(ret) +
-							 "\n err: (" + std::to_string(err) + ") " + gai_strerror(err),
-							 sinsp_logger::SEV_ERROR);
-				return false;
-			}
-		}
-		return true;
-	}
-
-	void dns_cleanup()
-	{
-		for(dns_list_t::iterator it = m_pending_dns_reqs.begin(); it != m_pending_dns_reqs.end();)
-		{
-			if(dns_req_done(it->get()))
-			{
-				it = m_pending_dns_reqs.erase(it);
-				g_logger.log("Socket handler: postponed canceling of DNS request succeeded, number of pending "
-							 "cancellation requests: " + std::to_string(m_pending_dns_reqs.size()),
-							 sinsp_logger::SEV_TRACE);
-			}
-			else { ++it; }
-		}
-
-		std::size_t pending_reqs = m_pending_dns_reqs.size();
-		if(pending_reqs)
-		{
-			g_logger.log("Socket handler: number of pending DNS cancellation requests is " + std::to_string(pending_reqs),
-						 (pending_reqs > 10) ? sinsp_logger::SEV_WARNING : sinsp_logger::SEV_TRACE);
-		}
-
-		if(!dns_req_done(m_dns_reqs.get()))
-		{
-			m_pending_dns_reqs.emplace_back(std::move(m_dns_reqs));
-		}
-		m_dns_reqs = nullptr;
-	}
-
 	void ssl_cleanup()
 	{
 		SSL_free(m_ssl_connection);
@@ -1559,10 +1442,10 @@ private:
 
 	void cleanup()
 	{
+		ares_destroy(m_ares_channel);
 		free(m_http_parser);
 		m_http_parser = nullptr;
 		close_socket();
-		dns_cleanup();
 		ssl_cleanup();
 	}
 
@@ -1691,17 +1574,6 @@ private:
 		return http_reason::get(status);
 	}
 
-	using gaicb_t = std::unique_ptr<struct gaicb* [], gaicb_free>;
-	using dns_list_t = std::deque<gaicb_t>;
-
-	gaicb_t make_gaicb(const std::string &host)
-	{
-		gaicb_t dns_reqs((struct gaicb**)calloc(1, sizeof(struct gaicb*)));
-		dns_reqs[0] = (struct gaicb*)calloc(1, sizeof(struct gaicb));
-		dns_reqs[0]->ar_name = strdup(m_url.get_host().c_str());
-		return dns_reqs;
-	}
-
 	T&                       m_obj;
 	std::string              m_id;
 	uri                      m_url;
@@ -1717,8 +1589,6 @@ private:
 	bool                     m_blocking = false;
 	std::vector<char>        m_buf;
 	int                      m_sock_err = 0;
-	gaicb_t m_dns_reqs = nullptr;
-	static dns_list_t        m_pending_dns_reqs;
 	ssl_ptr_t                m_ssl;
 	bt_ptr_t                 m_bt;
 	long                     m_timeout_ms;
@@ -1746,6 +1616,10 @@ private:
 	http_parser_data         m_http_parser_data;
 	unsigned                 m_data_limit = 524288; // bytes
 
+	ares_channel             m_ares_channel = nullptr;
+	ares_options             m_ares_opts;
+	ares_cb_result           m_ares_cb_res;
+
 	// older versions of kubernetes send pretty-printed JSON by default;
 	// that creates a problem with JSON-newline-delimit-based detection logic,
 	// which relies on JSON itself having no newlines; while there is a way to
@@ -1762,7 +1636,6 @@ template <typename T>
 const std::string socket_data_handler<T>::HTTP_VERSION_10 = "1.0";
 template <typename T>
 const std::string socket_data_handler<T>::HTTP_VERSION_11 = "1.1";
-template <typename T>
-typename socket_data_handler<T>::dns_list_t socket_data_handler<T>::m_pending_dns_reqs;
 
 #endif // HAS_CAPTURE
+#endif // MINIMAL_BUILD
\ No newline at end of file
