@@ -76,17 +76,17 @@ public:
 	/*!
 	  \brief Return the name of the process containing this thread, e.g. "top".
 	*/
-	std::string get_comm();
+	std::string get_comm() const;
 
 	/*!
 	  \brief Return the name of the process containing this thread from argv[0], e.g. "/bin/top".
 	*/
-	std::string get_exe();
+	std::string get_exe() const;
 
 	/*!
 	  \brief Return the full executable path of the process containing this thread, e.g. "/bin/top".
 	*/
-	std::string get_exepath();
+	std::string get_exepath() const;
 
 	/*!
 	  \brief Return the working directory of the process containing this thread.
@@ -238,6 +238,13 @@ public:
 	// readiness probe, or liveness probe.
 	bool is_health_probe();
 
+	/*!
+	  \brief Translate a directory's file descriptor into its path
+	  \param dir_fd  A file descriptor for a directory
+	  \return  A path (or "" if failure)
+	 */
+	std::string get_path_for_dir_fd(int64_t dir_fd);
+
 	//
 	// Core state
 	//
@@ -271,7 +278,7 @@ public:
 	int32_t m_tty;
 	int32_t m_loginuid; ///< loginuid (auid)
 
-	// In some cases, a threadinfo has a category that identfies
+	// In some cases, a threadinfo has a category that identifies
 	// why it was run. Descriptions:
 	// CAT_NONE: no specific category
 	// CAT_CONTAINER: a process run in a container and *not* any
@@ -454,6 +461,7 @@ VISIBILITY_PRIVATE
 class threadinfo_map_t
 {
 public:
+	typedef std::function<bool(const sinsp_threadinfo&)> const_visitor_t;
 	typedef std::function<bool(sinsp_threadinfo&)> visitor_t;
 	typedef std::shared_ptr<sinsp_threadinfo> ptr_t;
 
@@ -492,6 +500,18 @@ public:
 		m_threads.clear();
 	}
 
+	bool const_loop(const_visitor_t callback) const
+	{
+		for (const auto& it : m_threads)
+		{
+			if (!callback(*it.second.get()))
+			{
+				return false;
+			}
+		}
+		return true;
+	}
+
 	bool loop(visitor_t callback)
 	{
 		for (auto& it : m_threads)
