@@ -126,6 +126,15 @@ public:
 					   std::vector<uint16_t> *supp_ids);
 
 	static const char* event_name_by_id(uint16_t id);
+
+	static void ts_to_string(uint64_t ts, OUT std::string* res, bool date, bool ns);
+
+	static void ts_to_iso_8601(uint64_t ts, OUT std::string* res);
+
+        // Limited version of iso 8601 time string parsing, that assumes a
+        // timezone of Z for UTC, but does support parsing fractional seconds,
+        // unlike get_epoch_utc_seconds_* below.
+	static bool parse_iso_8601_utc_string(const std::string& time_str, uint64_t &ns);
 };
 
 ///////////////////////////////////////////////////////////////////////////////
