@@ -32,6 +32,9 @@ limitations under the License.
 #include "chisel.h"
 #include "scap_open_exception.h"
 #include "sinsp_capture_interrupt_exception.h"
+#ifdef HAS_CAPTURE
+#include "driver_config.h"
+#endif // HAS_CAPTURE
 #include "sysdig.h"
 #include "utils.h"
 
@@ -95,12 +98,14 @@ static void usage()
 "                    are millions of bytes (10^6, not 2^20). Use the -W flag to\n"
 "                    determine how many files will be saved to disk.\n"
 #ifdef HAS_CAPTURE
+#ifndef MINIMAL_BUILD
 " --cri <path>       Path to CRI socket for container metadata\n"
 "                    Use the specified socket to fetch data from a CRI-compatible runtime\n"
 "\n"
 " --cri-timeout <timeout_ms>\n"
 "                    Wait at most <timeout_ms> milliseconds for response from CRI\n"
-#endif
+#endif // MINIMAL_BUILD
+#endif // HAS_CAPTURE
 " -d, --displayflt   Make the given filter a display one\n"
 "                    Setting this option causes the events to be filtered\n"
 "                    after being parsed by the state system. Events are\n"
@@ -154,6 +159,7 @@ static void usage()
 #endif
 " -j, --json         Emit output as json, data buffer encoding will depend from the\n"
 "                    print format selected.\n"
+#ifndef MINIMAL_BUILD
 " -k <url>, --k8s-api=<url>\n"
 "                    Enable Kubernetes support by connecting to the API server\n"
 "                    specified as argument. E.g. \"http://admin:password@127.0.0.1:8080\".\n"
@@ -171,6 +177,7 @@ static void usage()
 "                    Note that the format of this command-line option prohibits use of files whose names contain\n"
 "                    ':' or '#' characters in the file name.\n"
 "                    Option can also be provided via the environment variable SYSDIG_K8S_API_CERT.\n"
+#endif // MINIMAL_BUILD
 " -L, --list-events  List the events that the engine supports\n"
 " -l, --list         List the fields that can be used for filtering and output\n"
 "                    formatting. Use -lv to get additional information for each\n"
@@ -510,7 +517,7 @@ void handle_end_of_file(bool print_progress, sinsp_evt_formatter* formatter = NU
 
 	//
 	// Reached the end of a trace file.
-	// If we are reporting prgress, this is 100%
+	// If we are reporting progress, this is 100%
 	//
 	if(print_progress)
 	{
@@ -775,9 +782,11 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 	bool filter_proclist_flag = false;
 	string cname;
 	vector<summary_table_entry> summary_table;
+#ifndef MINIMAL_BUILD
 	string* k8s_api = 0;
 	string* k8s_api_cert = 0;
 	string* mesos_api = 0;
+#endif // MINIMAL_BUILD
 	bool force_tracers_capture = false;
 	bool page_faults = false;
 	bool bpf = false;
@@ -786,6 +795,7 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 #ifdef HAS_CAPTURE
 	string cri_socket_path;
 #endif
+	bool udig = false;
 
 	// These variables are for the cycle_writer engine
 	int duration_seconds = 0;
@@ -836,6 +846,7 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 		{"snaplen", required_argument, 0, 's' },
 		{"summary", no_argument, 0, 'S' },
 		{"suppress-comm", required_argument, 0, 'U' },
+		{"udig", required_argument, 0, 'u' },
 		{"timetype", required_argument, 0, 't' },
 		{"force-tracers-capture", required_argument, 0, 'T'},
 		{"unbuffered", no_argument, 0, 0 },
@@ -868,7 +879,7 @@ sysdig_init_res sysdig_init(int argc, char **argv)
                                         "C:"
                                         "dDEe:F"
                                         "G:"
-                                        "hi:jk:K:lLm:M:n:Pp:qRr:Ss:t:TU:v"
+                                        "hi:jk:K:lLm:M:n:Pp:qRr:Ss:t:TU:uv"
                                         "W:"
                                         "w:xXz", long_options, &long_index)) != -1)
 		{
@@ -997,12 +1008,14 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 				//
 				jflag = true;
 				break;
+#ifndef MINIMAL_BUILD
 			case 'k':
 				k8s_api = new string(optarg);
 				break;
 			case 'K':
 				k8s_api_cert = new string(optarg);
 				break;
+#endif // MINIMAL_BUILD
 			case 'h':
 				usage();
 				delete inspector;
@@ -1014,9 +1027,11 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 				list_events(inspector);
 				delete inspector;
 				return sysdig_init_res(EXIT_SUCCESS);
+#ifndef MINIMAL_BUILD
 			case 'm':
 				mesos_api = new string(optarg);
 				break;
+#endif // MINIMAL_BUILD
 			case 'M':
 				duration_to_tot = atoi(optarg);
 				if(duration_to_tot <= 0)
@@ -1098,8 +1113,10 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 				break;
 			case 'r':
 				infiles.push_back(optarg);
+#ifndef MINIMAL_BUILD
 				k8s_api = new string();
 				mesos_api = new string();
+#endif // MINIMAL_BUILD
 				break;
 			case 'S':
 				for(uint32_t j = 0; j < PPM_EVENT_MAX; j++)
@@ -1135,10 +1152,12 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 			case 'T':
 				force_tracers_capture = true;
 				break;
-
 			case 'U':
 				suppress_comms.insert(string(optarg));
 				break;
+			case 'u':
+				udig = true;
+				break;
 			case 'v':
 				verbose = true;
 				break;
@@ -1451,15 +1470,22 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 					goto exit;
 				}
 
-				try
+				if(udig)
 				{
-					inspector->open("");
+					inspector->open_udig();
 				}
-				catch(const sinsp_exception& e)
+				else
 				{
-					open_success = false;
+					try
+					{
+						inspector->open("");
+					}
+					catch(const sinsp_exception& e)
+					{
+						open_success = false;
+					}
 				}
-
+				
 				//
 				// Starting the live capture failed, try to load the driver with
 				// modprobe.
@@ -1499,7 +1525,10 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 				//
 				// Enable gathering the CPU from the kernel module
 				//
-				inspector->set_get_procs_cpu_from_driver(true);
+				if(!udig)
+				{
+					inspector->set_get_procs_cpu_from_driver(true);
+				}
 			}
 
 			//
@@ -1536,6 +1565,7 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 			//
 			chisels_on_capture_start();
 
+#ifndef MINIMAL_BUILD
 			//
 			// run k8s, if required
 			//
@@ -1592,7 +1622,7 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 			}
 			delete mesos_api;
 			mesos_api = 0;
-
+#endif
 			cinfo = do_inspect(inspector,
 				cnt,
 				uint64_t(duration_to_tot*ONE_SECOND_IN_NS),
@@ -1638,6 +1668,12 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 		handle_end_of_file(print_progress);
 		res.m_res = e.scap_rc();
 	}
+	catch (const std::runtime_error& e) 
+	{
+		cerr << e.what() << endl;
+		handle_end_of_file(print_progress);
+		res.m_res = EXIT_FAILURE;
+	}
 	catch(...)
 	{
 		handle_end_of_file(print_progress);
